// 2004-03-02  Petur Runolfsson  <peturr02@ru.is>

// Copyright (C) 2004-2025 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

// { dg-require-effective-target hosted }

// 27.4.3 fpos

#include <iterator>
#include <testsuite_hooks.h>

class Fred
{
public:
  Fred(bool)
  { }
};

void barney(Fred)
{ }

// libstdc++/14320
void test01()
{
  using namespace std;

  typedef istreambuf_iterator<char>::difference_type Distance;
  
  Distance d = 0;
  barney(d);
}

int main()
{
  test01();
  return 0;
}
